package Acme::ManekiNeko;

our $VERSION='0.03';

our $MANEKINEKO=<<'EOM';

             db         db
            dpqb       dp8b
            8b qb_____dp_88
            88/ .        `p
            q'.            \
           .'.  .-.    ,-.  `--.
           |.  / 0 \  / 0 \ |   \
           |.  `.__   ___.' | \\/
           |.       "       | (
            \.    `-'-'    ,' |
           _/`------------'. .|
          /.  \\::(::[];)||.. \
         /.  ' \.`:;;;;'''/`. .|
        |.   |/ `;--._.__/  |..|
        |.  _/_,'''',,`.    `:.'
        |.     ` / ,  ',`.   |/
         \.   -'/\/     ',\  |\
          /\__-' /\ /     ,. |.\
         /. .|  '  /-.    ,: |..\
        :.  .|    /| | ,  ,||. ..:
        |.  .`     | '//` ,:|.  .|
        |..  .\      //\/ ,|.  ..|
         \.   .\     <./  ,'. ../
          \_ ,..`.__    _,..,._/
            `\|||/  `--'\|||/'

EOM

1;

=pod

=head1 NAME

Acme::ManekiNeko

=head1 SYNOPSIS

    use Acme::ManekiNeko; # This will make your Perl programs a lot more lucky.

=head1 NO REALLY

The fine CPAN testing people failed this module because it uses 'our', so it now requires
5.6 Perl, so if you can use this you really are more likely to have your program run to
completion, honest guv (no warranty!).

=head1 DESCRIPTION

"According to ancient legend, this cat stood in the doorway of the
Gotoku-ji temple and raised her paw in the traditional Japanese
beckoning gesture to a feudal lord who was passing by. The feudal lord
followed the cat into the temple and instantly, a lightning bolt
struck the place where the lord had been standing. Thus the cat had
saved his life. From then on, the Maneki Neko has been considered an
incarnation of the Goddess of Mercy."

Now your Perl programs can also benefit from good fortune by using
this module which invokes the image of Maneki Neko giving your
code luck.

=head1 AUTHOR

Greg McCarroll <greg@mccarroll.org.uk>

=end

